@@ -12,7 +12,7 @@ def api_request(request_creator_callable: Callable[..., Request]) -> Callable:
     def wrapper(*args, **kwargs) -> Response:
         session = Session()
         request = request_creator_callable(*args, **kwargs)
-        request.url = f"{settings.RESEARCH_ENVIRONMENT_API_URL}{request.url}"
+        request.url = f"{settings.CLOUD_RESEARCH_ENVIRONMENTS_API_URL}{request.url}"
         prepped = request.prepare()
         apply_api_credentials(prepped)
         return session.send(prepped)
