@@ -7,7 +7,7 @@ from django.conf import settings
 from environment.validators import gcp_billing_account_id_validator
 
 
-@skipIf(not settings.ENABLE_RESEARCH_ENVIRONMENTS, "Research environments are disabled")
+@skipIf(not settings.ENABLE_CLOUD_RESEARCH_ENVIRONMENTS, "Research environments are disabled")
 class BillingAccountValidatorTestCase(TestCase):
     def test_fails_for_invalid_regex(self):
         self.assertRaises(
